#
#   Humerus - Level Editor Screen
#

from pygame.locals import *
from pygame import draw
from albow.widget import Widget
from albow.controls import Label, Button, ImageButton, Row, Column, Frame
from albow.palette_view import PaletteView
from albow.resource import get_font, get_image, get_cursor
from screen import Screen, menu_button
import settings

#----------------------------------------------------------------------------

class EditorMenuScreen(Screen):

	def __init__(self, shell):
		Screen.__init__(self, shell)
		game = shell.game
		title = Label("Level Editor", font = get_font(24, "VeraBd.ttf"))
		def mb(title, action, enable = None):
			b = menu_button(title, action = action, enable = enable)
			b.fg_color = (255, 128, 0)
			return b
		items = [
			mb("New Level Set...", shell.new_level_set),
			mb("New Level",        shell.edit_new_level),
			mb("Edit Level",       shell.show_editor_level, game.level_present),
			mb("Load Level...",    shell.load_level),
			mb("Save Level",       shell.save_level,        game.level_present),
			mb("Save Level As...", shell.save_level_as,     game.level_present),
			mb("Exit Editor",      shell.show_menu),
		]
		menu = Column(items, align = 'l')
		box = Column([title, menu], align = 'l', spacing = 24)
		self.center(box)
	
	def key_down(self, e):
		if e.cmd:
			self.cmd_key(e)
		else:
			Screen.key_down(self, e)
	
	def cmd_key(self, e):
		key = e.key
		if key == K_n:
			self.shell.edit_new_level()
		elif key == K_e:
			self.shell.show_editor_level()
		elif key == K_o:
			self.shell.load_level()
		elif key == K_s:
			if e.shift:
				self.shell.save_level_as()
			else:
				self.shell.save_level()
		elif key == K_q:
			self.shell.show_menu()
		else:
			Screen.key_down(self, e)
	
	def exit_editor(self):
		level = self.game_current_level
		if level:
			level.testing = False
		self.shell.show_menu()

#----------------------------------------------------------------------------

class EditorLevelScreen(Screen):

	def __init__(self, shell):
		Screen.__init__(self, shell)

#----------------------------------------------------------------------------

class ChangeIndicator(Widget):

	dot_color = (255, 0, 0)

	def __init__(self, game):
		self.game = game
		Widget.__init__(self, Rect(0, 0, 10, 10))
	
	def draw(self, surf):
		frame = surf.get_rect()
		draw.rect(surf, self.fg_color, frame, 1)
		if self.game.current_level.changed:
			r = Rect(0, 0, 6, 6)
			r.center = frame.center
			surf.fill(self.dot_color, r)

