#
#   Humerus - Level
#

import os
from albow.sound import stop_sound
import constants, settings

RESET = 'reset'
PLAYING = 'playing'
SUCCEEDED = 'succeeded'
FAILED = 'failed'

class Level(object):
	#  game           Game
	#  changed        boolean
	#  pathname       string
	#  state          PLAYING, SUCCEEDED or FAILED
	#  is_tutorial    boolean
	#  testing        boolean
	
	level_file_suffix = constants.level_file_suffix
	level_file_magic = constants.level_file_magic
	level_file_version = constants.level_file_version

	changed = False
	is_tutorial = False
	testing = False
	
	def __init__(self):
		self.pathname = None
		self.state = None
	
	def reset(self):
		stop_sound()
		self.state = RESET
	
	def restart(self):
		self.reset()
		self.state = PLAYING
	
	def create_from_file(cls, r):
		if r.token <> cls.level_file_magic or not isinstance(r.args, int):
			r.error("Does not seem to be a %s level file" % constants.game_name)
		if r.args <> cls.level_file_version:
			r.error("Wrong file version, expected %s, got %s" % (
				cls.level_file_version, r.args))
		r.next_line()
		level = cls()
		level.read_from_file(r)
		return level
	
	create_from_file = classmethod(create_from_file)
	
	def read_from_file(self, r):
		self.pathname = r.path
		self.read_contents_from_file()
	
	def read_contents_from_file(self)
		raise NotImplementedError

	def write_to_file(self, f):
		f.write("%s %s\n" % (self.level_file_magic, self.level_file_version))
		self.write_contents_to_file(f)
	
	def write_contents_to_file(self, f):
		raise NotImplementedError

	def begin_frame(self):
		raise NotImplementedError
	
	def playing(self):
		return self.state == PLAYING

	def succeeded(self):
		return self.state == SUCCEEDED

	def failed(self):
		return self.state == FAILED

	def get_name(self):
		path = self.pathname
		if path:
			name = os.path.basename(path)
			return os.path.splitext(name)[0]
		else:
			return "Untitled"
	
	def get_filename(self):
		path = self.pathname
		if path:
			return os.path.basename(path)
		else:
			return None
